@@ -589,6 +589,18 @@ macro_rules! block {
     ($($tt:tt)*) => { $crate::usage!{$($tt)*} };
 }
 
+/// Avoid generating implicit constructors for this type.
+/// The rules for when to generate C++ implicit constructors
+/// are complex, and if autocxx gets it wrong, you can block
+/// such constructors using this.
+///
+/// A directive to be included inside
+/// [include_cpp] - see [include_cpp] for general information.
+#[macro_export]
+macro_rules! block_constructors {
+    ($($tt:tt)*) => { $crate::usage!{$($tt)*} };
+}
+
 /// The name of the mod to be generated with the FFI code.
 /// The default is `ffi`.
 ///
@@ -685,6 +697,9 @@ macro_rules! usage {
 #[doc(hidden)]
 pub use autocxx_macro::include_cpp_impl;
 
+#[doc(hidden)]
+pub use autocxx_macro::cpp_semantics;
+
 macro_rules! ctype_wrapper {
     ($r:ident, $c:expr, $d:expr) => {
         #[doc=$d]
@@ -811,6 +826,7 @@ pub mod prelude {
     pub use crate::c_ulonglong;
     pub use crate::c_ushort;
     pub use crate::c_void;
+    pub use crate::cpp_semantics;
     pub use crate::include_cpp;
     pub use crate::PinMut;
     pub use moveit::moveit;
